% This code produces all the welfare results using one solution of the
% model
clear;clc;
fprintf('Running: Compute_welfare_results\n');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% LOAD IN THE MINIMAL SET OF OBJECTS TO SOLVE THE MODEL:
load('Created_mat_files/baseline_no_tax','param','glob','mu_ij','z_ij','Mj','theta','eta');
options.surf_plot   = 'N';

%% Storage
varphi_vec          = [0.2,0.5,0.8];
sigma_vec           = [0,1.001,2];  % GHH then sigma=1.001 (log) and sigma = 2

Nvarphi             = numel(varphi_vec);
Nsigma              = numel(sigma_vec);

varphi_mat          = zeros(Nvarphi,Nsigma);
sigma_mat           = zeros(Nvarphi,Nsigma);

% Exact lambda's
lambdaE_mat         = zeros(Nvarphi,Nsigma);
lambdaE_mu_mat      = zeros(Nvarphi,Nsigma);
lambdaE_omega_mat   = zeros(Nvarphi,Nsigma);

% Aggregates
N_mat               = zeros(Nvarphi,Nsigma);
Nc_mat              = zeros(Nvarphi,Nsigma);
Y_mat               = zeros(Nvarphi,Nsigma);
Yc_mat              = zeros(Nvarphi,Nsigma);
W_mat               = zeros(Nvarphi,Nsigma);
Wc_mat              = zeros(Nvarphi,Nsigma);
AveWage_mat         = zeros(Nvarphi,Nsigma);
AveWagec_mat        = zeros(Nvarphi,Nsigma);
Nbodies_mat         = zeros(Nvarphi,Nsigma);
Nbodiesc_mat        = zeros(Nvarphi,Nsigma);

dlogAveWage_mat     = zeros(Nvarphi,Nsigma);
dlogAggEmp_mat      = zeros(Nvarphi,Nsigma);
dHHIwn_uw_mat       = zeros(Nvarphi,Nsigma);
dHHIwn_w_mat        = zeros(Nvarphi,Nsigma);

% Wedges
mu_mat              = zeros(Nvarphi,Nsigma);
omega_mat           = zeros(Nvarphi,Nsigma);

%% Solve baseline aggregate conditions
param.varphi                = 0.50;
param.sigma                 = 0;
options.solve_scale         = 'Y';
out                         = fun_welfare_closed_form(mu_ij,z_ij,Mj,[],[],param,glob,options);
glob.zbar                   = out.Ztilde;       % Scale from baseline calibration
glob.varphibar              = out.varphibar;
mu_base                     = out.mu;
omega_base                  = out.omega;
save('Created_mat_files/base_mu_omega','mu_base','omega_base');

%% Solve for alternative (varphi,sigma), recalibrating each time
for vv = (1:Nvarphi)
    for ss = (1:Nsigma)
        display(['vv/Nvarphi = ' num2str(vv/Nvarphi) ', ss/Nsigma = ' num2str(ss/Nsigma)]);
        
        param.varphi                = varphi_vec(vv);
        param.sigma                 = sigma_vec(ss);
        options.solve_scale         = 'Y';  % Recalibrate scale parameters to match data
        muc                         = 1;    % Competitive eq has muc=1
        omegac                      = 1;    % Competitive eq has omegac=1
        out                         = fun_welfare_closed_form(mu_ij,z_ij,Mj,muc,omegac,param,glob,options);
        
        lambdaE_mat(vv,ss)          = out.lambdaE;
        lambdaE_mu_mat(vv,ss)       = out.lambdaE_mu;
        lambdaE_omega_mat(vv,ss)    = out.lambdaE_omega;
        
        AveWage_mat(vv,ss)          = out.AveWage;
        AveWagec_mat(vv,ss)         = out.AveWagec;
        Nbodies_mat(vv,ss)          = out.Nbodies;
        Nbodiesc_mat(vv,ss)         = out.Nbodiesc;
        
        Y_mat(vv,ss)                = out.Y;
        Yc_mat(vv,ss)               = out.Yc;
        
        N_mat(vv,ss)                = out.N;
        Nc_mat(vv,ss)               = out.Nc;
        
        W_mat(vv,ss)                = out.W;
        Wc_mat(vv,ss)               = out.Wc;
        mu_mat(vv,ss)               = out.mu;
        
        dlogAveWage_mat(vv,ss)      = log(out.AveWagec/out.AveWage);
        dlogAggEmp_mat(vv,ss)       = log(out.AggEmpc/out.AggEmp);
        dHHIwn_uw_mat(vv,ss)        = out.HHIwnc_uw - out.HHIwn_uw;
        dHHIwn_w_mat(vv,ss)         = out.HHIwnc_w  - out.HHIwn_w ;
        
        varphi_mat(vv,ss)           = param.varphi;
        sigma_mat(vv,ss)            = param.sigma;
        
        mu_mat(vv,ss)               = out.mu;
        omega_mat(vv,ss)            = out.omega;
    end
end

ztilde          = out.ztilde;
Ztilde          = out.Ztilde;
alphatilde      = out.alphatilde;
alpha           = out.alpha;
gamma           = out.gamma;

%% Save out for welfare results table (all for sigma=0, ie GHH)
lambda_non_ghh_vec          = lambdaE_mat;
dhhi_wtd_vec                = dHHIwn_w_mat(:,1); %Hold sigma at 0, vary frisch
dhhi_uwtd_vec               = dHHIwn_uw_mat(:,1);
Wage_percent_change_vec     = 100*(AveWagec_mat(:,1)./AveWage_mat(:,1)-1);
Nbodies_percent_change_vec  = 100*(Nbodiesc_mat(:,1)./Nbodies_mat(:,1)-1);
Output_percent_change_vec   = 100*(Yc_mat(:,1)./Y_mat(:,1)-1);
frac_omega                  = lambdaE_omega_mat(:,1)./lambdaE_mat(:,1);
frac_mu                     = lambdaE_mu_mat(:,1)./lambdaE_mat(:,1);

varphi_vec                  = varphi_mat(:,1) ;
sigma_vec                   = sigma_mat(:,1) ;
Wc_vec                      = Wc_mat(:,1) ;        

save('Created_mat_files/Outputs_welfare','lambda_non_ghh_vec','dhhi_wtd_vec','dhhi_uwtd_vec',...
'Wage_percent_change_vec','Nbodies_percent_change_vec','Output_percent_change_vec',...
'frac_omega','frac_mu','mu_mat','omega_mat','theta','eta','alpha','gamma','varphi_vec','sigma_vec','Wc_vec'); 

return
