%% Figure 4C - Reduced form and structural labor supply elasticities
clear; clc;
fprintf('Running: Figure 4C - Reduced form and structural labor supply elasticities\n');
%_________________________________________________________________________
% INPUTS: 
% --- Solved equilibrium of the model with corporate taxes
% 		baseline_tax.mat
% --- Previous m-files: recover_baseline_tax.m
% OUTPUTS:
% --- Figure plotting reduced  form and structural elasticities as a function 
% 	  of payroll share
% --- Figure_4C_Labor_Supply_Elasticity_vs_Share_eps.png
%_________________________________________________________________________
load Created_mat_files/baseline_tax
fprintf('Figure_4C_Labor_Supply_Elasticity_vs_Share\n');

%% Data
% From "date t labor supply elast"
epsilon_t = [1.244
1.220
1.195
1.168
1.141
1.112
1.082
1.050
1.017
0.983
0.946
0.908
0.868
0.825
0.780
0.732];

% From "date t+1 labor supply elast"
epsilon_tp1 = [2.150
2.121
2.089
2.055
2.018
1.978
1.936
1.889
1.839
1.784
1.724
1.657
1.583
1.502
1.410
1.306];

%% Elasticities of labor supply

% Data: Equally weighted average of date t+1 and date t empirical labor
% supply elasticity estimates
epsilon_D       = 0.5*(epsilon_t+epsilon_tp1);

% Vector of shares for plotting
s               = (0:0.01:0.15)';  

% Reduced form elasticity of labor supply from simulated model
epsilon_M       = (STAT(121) + STAT(123).*s)./(STAT(124) + STAT(126).*s);

% Structural elasticity of labor supply
eta             = x(1);
theta           = x(2);
varepsilon_M    = (s.*(1/theta) + (1-s).*(1/eta)).^(-1);

%% FIGURE
F1 = figure(1);
set(F1,'Pos',[1177 502 689 540]);
set(0,'defaultlinelinewidth',2);
ms = 12;
lw = 3;

plot(s,epsilon_D,'bx:','markersize',ms,'linewidth',lw);hold on; grid on;
plot(s,epsilon_M,'bo-','markersize',ms,'linewidth',lw);hold on; grid on;
plot(s,varepsilon_M,'ro-','markersize',ms,'linewidth',lw);hold on;
title('C. Data and model','interpreter','latex');
xlabel('Payroll share $s^{wn}_{ij}$','interpreter','latex');
ylabel('Labor supply elasticity','interpreter','latex');
l = legend(...
            'Data - Reduced form $\:\:\:$- $\widehat{\epsilon}(s)$',...
           'Model - Reduced form $\,$- $\:\:\widehat{\epsilon}^{Model}(s,\theta,\eta)$',...
           'Model - Structural $\:\:\:\:\:\:\:\:$- $\:\:\varepsilon(s,\theta,\eta)$');
set(l,'location','NorthEast','interpreter','latex','fontsize',17);
set(gca,'Xtick',[0:0.02:0.15]);
set(gca,'ticklabelinterpreter','latex');
set(gca,'fontsize',20);
ytickformat('%2.1f') 
xlim([0,0.10]);
 ylim([0,12]);

print -depsc Created_figure_files/Figure_4C_Labor_Supply_Elasticity_vs_Share_eps.eps
return
