%% Figure 8I: Employment reallocation from the benchmark economy to the efficient economy
clear;clc;close all;
fprintf('Running: Figure 8I: Employment reallocation from the benchmark economy to the efficient economy\n');
%__________________________________________________________________________
% LOAD IN THE MINIMAL SET OF OBJECTS TO SOLVE THE MODEL:
load('Created_mat_files/baseline_no_tax','param','glob','mu_ij','z_ij','Mj');
%__________________________________________________________________________
% Solve baseline and competitive (efficient) economies
param.varphi                = 0.50;
param.sigma                 = 0;
options.solve_scale         = 'Y';
mu1                         = 1;    % Efficient economy agg. markdown
omega1                      = 1;    % Efficient economy agg. misallocation
out                         = fun_welfare_closed_form(mu_ij,z_ij,Mj,mu1,omega1,param,glob,options);
glob.zbar                   = out.Ztilde;
glob.varphibar              = out.varphibar;
%__________________________________________________________________________
% Computations
pvec        = [0:5:100]';       % Percentiles
z0_i        = z_ij(z_ij>0);
n0_i        = out.n_ij(z_ij>0);
n1_i        = out.nc_ij(z_ij>0);

zcut        = prctile(z0_i,pvec);
Nbin        = numel(zcut)-1;
N0_bin      = zeros(Nbin,1);        % Total bin employment in oligopsony
N1_bin      = zeros(Nbin,1);        % Total bin employment in competitive

for bb = (1:Nbin)
   xxx              = (z0_i>=zcut(bb)) & (z0_i<=zcut(bb+1));
   N0_bin(bb)       = sum(n0_i(xxx));
   N1_bin(bb)       = sum(n1_i(xxx));
end

% Average
dN      = 100*(N1_bin-N0_bin)./N0_bin;

%% Figure
F1 = figure(1);
set(F1,'Pos',[177 558 547 420]);
font        = 18;

xvec        = 0.5*(pvec(2:end)+pvec(1:end-1)); 
xtickvec    = [0:10:100];

subplot(1,1,1);
bar(xvec,dN,'facecolor','b'); hold on;grid on;
plot([-100,200],[0,0],'k-','linewidth',1); hold on;grid on;
set(gca,'Xtick',xtickvec);
l = legend('Change in bin employment');
set(l,'interpreter','latex','location','southeast','fontsize',font);
xlabel('Productivity percentiles','interpreter','latex');
ylabel('Employment change, \%','interpreter','latex','fontsize',16);
set(gca,'ticklabelinterpreter','latex','fontsize',font);
title('I. Employment reallocation (model)','interpreter','latex');
xlim([0,100]);
ylim([-75,75]);
ytickformat('%3.0f');xtickformat('%3.0f');
set(gca,'ytick',100*[-0.5:0.25:0.5]);

print '-depsc' Created_figure_files/Figure_8I_Employment_Reallocation_eps 
