%% Figure A2: Identification of productivity dispersion ?, and DRS ?
clear all
close all
dbstop if error 
fprintf('Running: Figure_A2_Identification.m\n');
%__________________________________________________________________________
% SETUP
X           = load('Input_parameter_vectors/xmin_B_whole_economy');
x           = X.xmin;
m_data      = X.m_data;
%__________________________________________________________________________
% Grid of parameters for comparative statics
Np          = 10;
alpha_min   = 0.70;
alpha_max   = 0.999;
xi_min      = 0.10;
xi_max      = 0.50;    
xi_vec      = linspace(xi_min,xi_max,Np);
alpha_vec   = linspace(alpha_min,alpha_max,Np);
%__________________________________________________________________________
% STORAGE:
hhi_mat     = zeros(Np,2);
ls_mat      = zeros(Np,2);
%__________________________________________________________________________
% XI: SOLVE MODEL VARYING XI
fprintf('Looping over counterfactual xi\n');
for pp = (1:Np)
    fprintf('Xi, pp = %2i of %2i\n',pp,Np);
    X               = load('Input_parameter_vectors/xmin_B_whole_economy');
    x               = X.xmin;
    x(3)            = xi_vec(pp);
    Compute_baseline_no_tax_change_parameters;
    hhi_mat(pp,1)   = STAT(26);
    ls_mat(pp,1)    = STAT(17);
end
%__________________________________________________________________________
% ALPHA: SOLVE MODEL VARYING ALPHA
fprintf('Looping over counterfactual alpha\n');
for pp = (1:Np)
    fprintf('Alpha, pp = %2i of %2i\n',pp,Np);
    X               = load('Input_parameter_vectors/xmin_B_whole_economy');
    x               = X.xmin;
    x(4)            = alpha_vec(pp);
    Compute_baseline_no_tax_change_parameters;
    hhi_mat(pp,2)   = STAT(26);
    ls_mat(pp,2)    = STAT(17);
end

%% Figure;
clc;
load 'Created_mat_files/baseline_no_tax';

hhi_base            = STAT(26);
ls_base             = STAT(17);
xi_base             = x(3);
alpha_base          = x(4);

alphatilde_base     = alpha_base;
xitilde_base        = xi_base;

alpha_base          = (1-Delta)*alphatilde_base + Delta;
gamma               = 1-Delta/alpha_base;
xi_base             = (1-(1-gamma)*alpha_base)*xi_base;

% Comparative static vectors are in 'tilde' form
alphatilde_vec      = alpha_vec;
xitilde_vec         = xi_vec;
% Transform the comparative static vectors of parameters
alpha_vec           = (1-Delta)*alphatilde_vec + Delta;
xi_vec              = (1-(1-gamma)*alpha_vec).*xi_vec;

% Compute implied labor share using only the direct formula
ls_hhi = @(hhi,alpha) alpha*gamma*(hhi*(theta+1)/theta + (1-hhi)*(eta+1)/eta).^(-1);
fprintf('ls_base = %3.4f\t,\t ls(hhi_base) = %3.4f\n',ls_base,ls_hhi(hhi_base,alpha_base));

ls_constant_hhi     = zeros(Np,1);
ls_constant_alpha   = zeros(Np,1);
for pp = (1:Np)
    ls_constant_hhi(pp)     = ls_hhi(hhi_base,alpha_vec(pp));
    ls_constant_alpha(pp)   = ls_hhi(hhi_mat(pp,2),alpha_base);
end
 
%% FIGURE
F1 = figure(1);
set(F1,'Pos',[405 317 1070 653]);
font = 12;
set(0,'defaultlinelinewidth',1);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
subplot(2,2,1);
plot(xi_vec,hhi_mat(:,1),'ko-','linewidth',3);hold on;grid on;
plot([xi_base,xi_base],[0,1],'k-');hold on;
plot([-10,10],[hhi_base,hhi_base],'k-');hold on;

x       = xi_vec;
y       = hhi_mat(:,1);
x_lower = [x];
x_upper = fliplr(x_lower);
y_lower = min(y)*ones(size(x));
y_upper = max(y)*ones(size(x));
bg      = fill([x_lower,x_upper]',[y_lower';y_upper'],'r','linewidth',0.001,'LineStyle','none'); hold on;
set(bg,'FaceColor',rgb('Green'),'FaceAlpha',0.05); hold on;

xlim([min(xi_vec),max(xi_vec)]);
ylim([min(hhi_mat(:,1)),max(hhi_mat(:,1))]);
xlabel('Productivity dispersion: $\sigma_z$','interpreter','latex');
ylabel('Payroll HHI','interpreter','latex');
title('A. HHI vs. $\sigma_z$','interpreter','latex');
ytickformat('%3.2f');xtickformat('%3.2f');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
subplot(2,2,2);
plot(xi_vec',ls_mat(:,1),'ko-','linewidth',3);hold on;grid on;
plot([xi_base,xi_base],[0,1],'k-');hold on;
plot([-10,10],[ls_base,ls_base],'k-');hold on;

x       = xi_vec;
y       = ls_mat(:,1);
x_lower = [x];
x_upper = fliplr(x_lower);
y_lower = min(y)*ones(size(x));
y_upper = max(y)*ones(size(x));
bg      = fill([x_lower,x_upper]',[y_lower';y_upper'],'r','linewidth',0.001,'LineStyle','none'); hold on;
set(bg,'FaceColor',rgb('Red'),'FaceAlpha',0.05); hold on;

xlim([min(xi_vec),max(xi_vec)]);
ylim([min(ls_mat(:,1)),max(ls_mat(:,1))]);
xlabel('Productivity dispersion: $\sigma_z$','interpreter','latex');
ylabel('Labor share','interpreter','latex');
title('B. Labor share  vs. $\sigma_z$','interpreter','latex');
ytickformat('%3.2f');xtickformat('%3.2f');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
subplot(2,2,3);
plot(alpha_vec,hhi_mat(:,2),'ko-','linewidth',3);hold on;grid on;
plot([alpha_base,alpha_base],[0,1],'k-');hold on;
plot([-10,10],[hhi_base,hhi_base],'k-');

x       = alpha_vec;
y       = hhi_mat(:,2);
x_lower = [x];
x_upper = fliplr(x_lower);
y_lower = min(y)*ones(size(x));
y_upper = max(y)*ones(size(x));
bg      = fill([x_lower,x_upper]',[y_lower';y_upper'],'r','linewidth',0.001,'LineStyle','none'); hold on;
set(bg,'FaceColor',rgb('Green'),'FaceAlpha',0.05); hold on;

xlim([min(alpha_vec),max(alpha_vec)]);
ylim([min(hhi_mat(:,2)),max(hhi_mat(:,2))]);
xlabel('Decreasing returns: $\alpha$','interpreter','latex');
ylabel('Payroll HHI','interpreter','latex');
title('C. HHI vs. $\alpha$','interpreter','latex');
ytickformat('%3.2f');xtickformat('%3.2f');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
subplot(2,2,4);
lsvec = [ls_mat(:,2);ls_constant_hhi;ls_constant_alpha];

plot(alpha_vec,ls_mat(:,2),'ko-','linewidth',3);hold on;grid on;
plot(alpha_vec,ls_constant_hhi,'bd-.','linewidth',3);hold on;grid on;
plot(alpha_vec,ls_constant_alpha,'rs:','linewidth',3,'markersize',10);hold on;grid on;
plot([alpha_base,alpha_base],[0,1],'k-');hold on;
plot([-10,10],[ls_base,ls_base],'k-');

x       = alpha_vec;
y       = lsvec;
x_lower = [x];
x_upper = fliplr(x_lower);
y_lower = min(y)*ones(size(x));
y_upper = max(y)*ones(size(x));
bg      = fill([x_lower,x_upper]',[y_lower';y_upper'],'r','linewidth',0.001,'LineStyle','none'); hold on;
set(bg,'FaceColor',rgb('Green'),'FaceAlpha',0.05); hold on;

xlim([min(alpha_vec),max(alpha_vec)]);
ylim([min(lsvec),max(lsvec)]);
l = legend('Combined effects','From formula: $\uparrow\alpha$','From formula: $\uparrow HHI$');
set(l,'interpreter','latex','location','southeast','fontsize',font);
xlabel('Decreasing returns: $\alpha$','interpreter','latex');
ylabel('Labor share','interpreter','latex');
title('D. Labor share vs. $\alpha$','interpreter','latex');
ytickformat('%3.2f');xtickformat('%3.2f');
set(gca,'fontsize',font,'ticklabelinterpreter','latex');
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
print '-depsc' Created_figure_files/Figure_A2_Identification_eps
