%% Figure A3: Oligopsonistic equilibrium with varying decreasing returns ?
clear;close all;
load('Created_mat_files/baseline_no_tax');
dbstop if error;
fprintf('Running: Figure_A3_Varying_Decreasing_Returns.m\n');

%% Set up productivities and vector of alpha's
Z0x     = z_ij(z_ij~=0);    % Take out all positive productivities
Qvec    = [10,50,90];
Zq      = prctile(Z0x,Qvec);

K       = numel(Zq);
M_max   = numel(Zq);
M       = zeros(K,1);
Z0      = zeros(M_max,K);
for kk = (1:K)
    M(kk)           = kk;
    for kkk = 1:3
        Z0(kkk,kk)  = Zq(kkk);          
    end
end
M(:)     = 3;

alphavec = [0.50,0.75,1];

%% Solve model for different values of alpha
mu_ij           = zeros(M_max,K);      % Markdown
what_ij         = zeros(M_max,K);      % Wage
w_ij            = zeros(M_max,K);      % Wage
for jj=(1:K)  % J regions
    param.alpha            = alphavec(jj);
    z_i                    = Z0(1:M(jj),jj); % Isolate productivity vector in region
    eq0                    = fun_solve_market_Nash(z_i,param,val,glob,options);
    mu_ij(1:M(jj),jj)      = eq0.mu_i;
    what_ij(1:M(jj),jj)    = eq0.w_i;
    w_ij(:,jj)      = omega^(1/(1+(1-alpha)*theta)) * W^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij(:,jj);
end
w_j             = sum(w_ij.^(eta+1)).^(1/(eta+1));
n_ij            = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij,w_j).^eta,(w_j/W).^theta).*(W/1).^varphi;
swn_ij          = bsxfun(@rdivide,w_ij.*n_ij,sum(w_ij.*n_ij));

%% FIGURE
F9      = figure(round(1000*rand));
set(F9,'Pos',[1          41        1920         963]);
font    = 28;
set(0,'defaultlinelinewidth',3);
set(0,'defaultlinemarkersize',15);
clf;
%__________________________________________________________________________
% A. SHARES
subplot(2,2,1);
X           = swn_ij;
X(X==0)     = NaN;
plot(Qvec,X(:,3),'o-','color',rgb('Green'));hold on;
plot(Qvec,X(:,2),'x-','color',rgb('Blue'));hold on;
plot(Qvec,X(:,1),'s-','color',rgb('Red'));hold on;grid on;
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
title('A. Share of market payroll: $s^{wn}_{ij}$','interpreter','latex','fontsize',font);
set(gca,'YTick',[0,0.25,0.50,0.75,1.0],'YTickLabel',{'0','0.25','0.50','0.75','1.00'});
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
l = legend('High $\alpha$','Med $\alpha$','Low $\alpha$');
set(l,'location','SouthEast','interpreter','latex','fontsize',font-4);
hold on;
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
%__________________________________________________________________________
% B. MARKDOWNS
subplot(2,2,2);
X           = mu_ij;
X(X==0)     = NaN; 
plot(Qvec,X(:,1),'s-','color',rgb('Red'));hold on;
plot(Qvec,X(:,2),'x-','color',rgb('Blue'));hold on;
plot(Qvec,X(:,3),'o-','color',rgb('Green'));hold on;grid on;
ylim([0.35,0.89]);
set(gca,'YTick',[theta/(theta+1),0.40,0.50,0.60,0.70,0.80,eta/(eta+1),1]);
set(gca,'YTickLabel',{'$\frac{\theta}{\theta+1}$','0.40','0.50','0.60','0.70','0.80','$\frac{\eta}{\eta+1}$','1'});
ylim([0.25,1]);
title('B. Markdown: $\mu_{ij} = \frac{\varepsilon(s^{wn}_{ij})}{\varepsilon(s^{wn}_{ij})+1}$','interpreter','latex','fontsize',font);
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
plot([0,100],[eta/(eta+1),eta/(eta+1)],'k--');hold on;
plot([0,100],[theta/(theta+1),theta/(theta+1)],'k:');hold on;
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
%__________________________________________________________________________
% C. WAGES
subplot(2,2,3);
X           = w_ij/1000;
X(X==0)     = NaN;
plot(Qvec,X(:,1),'s-','color',rgb('Red'));hold on;
plot(Qvec,X(:,2),'x-','color',rgb('Blue'));hold on;
plot(Qvec,X(:,3),'o-','color',rgb('Green'));hold on;grid on;
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
title('C. Wage (\$000s): $w_{ij} = \mu_{ij}MRPL_{ij}$','interpreter','latex','fontsize',font);
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');
%__________________________________________________________________________
% D. EMPLOYMENT
subplot(2,2,4);
X           = n_ij;
X(X==0)     = NaN;
plot(Qvec,X(:,1),'s-','color',rgb('Red'));hold on;
plot(Qvec,X(:,2),'x-','color',rgb('Blue'));hold on;
plot(Qvec,X(:,3),'o-','color',rgb('Green'));hold on;grid on;
set(gca,'YTick',[0:100:500]);
xlim([min(Qvec),max(Qvec)]);
set(gca,'XTick',Qvec);
set(gca,'XTick',[10,50,90],'XTickLabel',{'$z_{Low}$','$z_{Med}$','$z_{High}$'});xlim([5,95]);
title('D. Employment: $n_{ij}$','interpreter','latex','fontsize',font);
set(gca,'fontsize',font-4,'ticklabelinterpreter','latex');

%% SAVE
set(gcf,'PaperPositionMode','auto');
print '-depsc' 'Created_figure_files/Figure_A3_Varying_Decreasing_Returns_eps'
