%% Figure G1: Non-wage benefits and wage-bill shares
clear;clc; close all;

load Created_mat_files/baseline_tax
fprintf('Running: Figure_G1_Non_Wage_Benefits_and_Shares.m\n');

%% COMPUTATIONS
% To make this comparable with what is in the data we compute:
% percent change in structural markdown with respect to a 1 percentage point increase in s
s           = [0.01:0.01:0.15]';                        % Percentage point increases in s
mu          = [(1/theta)*s + (1/eta)*(1-s)].^(-1);      % Structural markdowns
emus        = (mu(2:end)-mu(1:end-1))./mu(1:end-1);     % Percentage change
%__________________________________________________________________________
% Elasticity of benefits to 1ppt change in share from Census results
ebs         = 0.00597; 	

%% FIGURE

F1 = figure(1);
set(F1,'Pos',[211.6667 97.6667 756 477.3333]);
set(0,'defaultlinelinewidth',3);
set(0,'defaultlinemarkersize',9);
font = 16;

plot(s(1:end-1),emus*100,'ro-','markersize',8,'linewidth',2); grid on; hold on;
plot(s(1:end-1),ebs*ones(size(emus))*100,'bx-','markersize',8,'linewidth',2); grid on;
l = legend('Elasticity of $\mu(s)$ w/r/t $s$ (Model)','Elasticity of benefits per worker w/r/t $s$ (Data)');
set(l,'interpreter','latex','location','best');
xlabel('Share','interpreter','latex');
ylabel('Elasticity','interpreter','latex');
set(gca,'ticklabelinterpreter','latex','fontsize',15);
xtickformat('%3.2f');
ytickformat('%3.2f');
ylim([-20,5]);

print '-depsc' Created_figure_files/Figure_G1_Non_Wage_Benefits_and_Shares_eps

return