%% Table 3 - Summary of parameters
clear;clc;
fprintf('Running: Table 3 - Summary of parameters\n');

%%  TRADEABLE INDUSTRIES - TAX SIMULATION
load Created_mat_files/baseline_tax
fprintf('Table_3_Summary_of_Parameters\n');

% Back out alpha and gamma
alphatilde  = alpha;
alpha_true  = (1-Delta)*alphatilde + Delta;
gamma       = (alpha_true-Delta)/alpha_true;
% Convert lambdaC to DeltaC
DeltaC      = 1+log(1+lambdaC);

fid = fopen('Created_table_files/Table_3_Summary_of_Parameters.tex','w');
fprintf(fid,'\\begin{tabular}{llrlcc}\n');
fprintf(fid,'\\toprule\n');
fprintf(fid,' \\multicolumn{2}{l}{\\textbf{Parameter}}  &  \\textbf{Value} & \\textbf{Moment} & \\textbf{Model}  & \\textbf{Data} \\\\ \n');
fprintf(fid,'\\midrule \n');
fprintf(fid,' \\multicolumn{6}{l}{\\redSM{\\sc{I. \\textbf{Tradeable industries only}}}} \\\\ \n');
fprintf(fid,'\\midrule \n');
fprintf(fid,' $G(m_j)$ & Pareto and point mass at $m_j=1$ & & \\multicolumn{3}{l}{Mean, Variance, Skewness of distribution} \\\\ \n');
fprintf(fid,'   &  & & \\multicolumn{3}{l}{15 percent of markets have 1 firm} \\\\ \n');
fprintf(fid,' $\\omega_C$ &             Share of firms that are $C$-corps & %3.2f & \\multicolumn{3}{l}{Share of estabs. that are $C$-corps (CBP, 2014)} \\\\ \n',share_ccorp);
fprintf(fid,' $\\tau_C$ &               State corporate tax rate          & %3.3f & \\multicolumn{3}{l}{Mean of state corp. tax rate $\\tau_{C,st}$} \\\\ \n',tauC);
fprintf(fid,' $\\Delta_{\\tau}$  &       State corporate tax rate increase & %3.3f & \\multicolumn{3}{l}{Std. dev. of annual $\\tau_{C,st}$} \\\\ \n',tauCprime-tauC);
fprintf(fid,' $\\lambda_K$ &            Fraction of capital debt financed & %3.3f & Tradeable industries (Compustat, 2014) & & \\\\ \n',lambdaK);

fprintf(fid,'\\midrule \n');
fprintf(fid,'\\multicolumn{6}{l}{\\emph{Estimated}}\\\\ \n');
fprintf(fid,' $\\theta$ & Across market substitutability & %3.2f ',theta);
    fprintf(fid, '& Average $\\widehat{\\epsilon}^{Data}(s)$ for $s\\in[0.05,0.10]$  & %3.2f & %3.2f \\\\ \n', STAT(129),m_data(129));
fprintf(fid,' $\\eta$ & Within market substitutability & %3.2f ',eta);
    fprintf(fid, '& Average $\\widehat{\\epsilon}^{Data}(s)$ for $s\\in[0,0.05]$ & %3.2f & %3.2f \\\\ \n', STAT(128),m_data(128));
fprintf(fid,' $\\Delta_C$ & Relative productivity of $C$-corps  & %3.2f ',DeltaC);
    fprintf(fid, '& Employment share of $C$-corps & %3.2f & %3.2f \\\\ \n', STAT(127),m_data(127));
fprintf(fid,'$\\sigma_{{z}}$  &  Productivity dispersion  & %2.3f ',xi);
    fprintf(fid, '& Payroll weighted $\\mathbb{E}[hhi_j^{wn}]$ & %3.2f & %3.2f \\\\ \n', STAT(26),m_data(26));
fprintf(fid,'$\\alpha$  &  Decreasing returns to scale  & %3.3f  ',alpha_true);
    fprintf(fid, '& Labor share & %3.2f & %3.2f \\\\ \n', STAT(17),m_data(17));
fprintf(fid,'$\\gamma$  &  Exponent on labor & %3.3f  ',gamma);
    fprintf(fid, '& Capital share  & %3.2f & %3.2f \\\\ \n',  STAT(16),m_data(16));
fprintf(fid,'$\\overline{Z}$  &  Productivity shifter  & %2.2f$\\times 10^4$ ',zbar/10000);
    fprintf(fid, '& Mean firm size & %3.1f & %3.1f \\\\ \n', STAT(35),glob.AveFirmSize_data);
fprintf(fid,'$\\overline{\\varphi}$  &  Labor disutility shifter  & %2.3f ',varphibar);
    fprintf(fid, '& Mean worker earnings (\\$000) & %3.1f & %3.1f \\\\ \n', STAT(32)/STAT(35),glob.AveEarnings_data/1000);

%%  ALL INDUSTRIES - NO TAX SIMULATION
load Created_mat_files/baseline_no_tax

% Back out alpha and gamma
alphatilde  = alpha;
alpha_true  = (1-Delta)*alphatilde + Delta;
gamma       = (alpha_true-Delta)/alpha_true;

fprintf(fid,'\\midrule\n');
fprintf(fid,' \\multicolumn{6}{l}{\\redSM{\\sc{II. \\textbf{All industries}}}} \\\\ \n');
fprintf(fid,'\\midrule \n');
fprintf(fid,' $G(m_j)$ & Pareto and point mass at $m_j=1$ & & \\multicolumn{3}{l}{Mean, Variance, Skewness of distribution} \\\\ \n');
fprintf(fid,'   &  & & \\multicolumn{3}{l}{9 percent of markets have 1 firm} \\\\ \n');
fprintf(fid,' $\\theta$ & Across market substitutability & %3.2f ',theta);
    fprintf(fid, '& \\multicolumn{3}{l}{Held fixed at estimated tradeable value  } \\\\ \n' );
fprintf(fid,' $\\eta$ & Within market substitutability & %3.2f ',eta);
    fprintf(fid, '& \\multicolumn{3}{l}{Held fixed at estimated tradeable value  }  \\\\ \n' );
fprintf(fid,'\\midrule \n');
fprintf(fid,'\\multicolumn{6}{l}{\\emph{Estimated}}\\\\ \n');
fprintf(fid,'$\\sigma_{{z}}$  &  Productivity dispersion  & %2.3f ',xi);
    fprintf(fid, '& Payroll weighted $\\mathbb{E}[hhi_j^{wn}]$ & %3.2f & %3.2f \\\\ \n', STAT(26),m_data(26));
fprintf(fid,'$\\alpha$  &  Decreasing returns to scale  & %3.3f  ',alpha_true);
    fprintf(fid, '& Labor share & %3.2f & %3.2f \\\\ \n', STAT(17),m_data(17));
fprintf(fid,'$\\gamma$  &  Exponent on labor & %3.3f  ',gamma);
    fprintf(fid, '& Capital share  & %3.2f & %3.2f \\\\ \n',  STAT(16),m_data(16));
fprintf(fid,'$\\overline{Z}$  &  Productivity shifter  & %2.2f$\\times 10^4$ ',zbar/10000);
    fprintf(fid, '& Mean firm size & %3.1f & %3.1f \\\\ \n', STAT(35),glob.AveFirmSize_data);
fprintf(fid,'$\\overline{\\varphi}$  &  Labor disutility shifter  & %2.3f ',varphibar);
    fprintf(fid, '& Mean worker earnings (\\$000) & %3.1f & %3.1f \\\\ \n', STAT(32)/STAT(35),glob.AveEarnings_data/1000);
fprintf(fid,'\\bottomrule \n');
fprintf(fid,'\\end{tabular}');
fclose(fid);


return
