%% Table 4: Strategic interaction and replication of Staiger, Spetz and Phibbs (2010)
clear all
close all
dbstop if error 
fprintf('Running: Table_4_Strategic_Interaction_Replication_of_SSP.m\n');
%__________________________________________________________________________
X                   = load('Input_parameter_vectors/xmin_B_whole_economy');
x                   = X.xmin;       % Parameters
m_data              = X.m_data;     % Target moments
%__________________________________________________________________________
% OPTIONS
options.iter_S_max  = 100       ;  % Max iterations over wage shares in Nash equilibrium solver
options.tol_S       = 1e-5      ;  % Tolerance for wage shares
options.upsilon     = 0.20      ;  % Adjustment rate of shares in equilibrium solver
%__________________________________________________________________________
% OUTPUT OPTIONS
options.print       = 'Y';
options.tradeable   = 'N'; 

glob.J              = 5000;     % Number of markets (j=1,...,J)
if strcmp(options.tradeable,'Y')
    glob.Ndist      = load('Created_mat_files/Nfit');       % Load results from Figure_F1A_Table_F1_Fit_Mj_Distribution_Tradeable_Ind.m
else
    glob.Ndist      = load('Created_mat_files/Nfit_all');   % Load results from Figure_F1B_Table_F2_Fit_Mj_Distribution_All_Ind.m
end
options.Mj_max      = max(max(glob.Ndist.M_j))      ; % Cap firms if region has more than X firms -- hard coded in fit_firm_dist_gp_II_2014

% Parameters
glob.varphi         = 0.50;             % Frisch
glob.beta           = 1/1.04;           % Discount factor
glob.delta          = 0.1;              % Depreciation rate

% Corpporate tax shock parameters
glob.share_ccorp    = 0.31;         % table_4_market_stats_v1_2014
glob.tauC_shock_size= 0;            % No corporate tax shock
glob.tauC           = 0;            % No corporate tax
glob.lambdaK 		= 0;            % No distinction between Ccorp and non-Ccorp

% Tradeable
if strcmp(options.tradeable,'Y')
    glob.AveFirmSize_data = 34.63;
    glob.AveEarnings_data = (2018*1000)/34.63;
else
    glob.AveFirmSize_data = 22.83;
    glob.AveEarnings_data = (1000*1000)/22.83;
end

%% A. CALIBRATION
options.solve_scale     = 'Y'; 
%__________________________________________________________________________
% FIX SEED
 rng('default');
%__________________________________________________________________________
% SETUP / UNPACK
param.eta           = x(1); 
param.theta         = x(2);
param.xi            = x(3);
param.alpha         = x(4);
param.lambdaC       = x(5);
param.Delta         = x(6);

share_ccorp         = glob.share_ccorp          ; %set this parameter in the sampling to yield actual_share_ccorp fraction of firms as ccorps
beta                = glob.beta                 ; %Discount factor
delta               = glob.delta                ; %Depreciation rate
tauC_shock_size     = glob.tauC_shock_size      ; %Shock size
tauC                = glob.tauC                 ; %Corporate tax rate
Delta               = param.Delta ;
R                   = (1/beta)-1+delta; % Rental rate=r+delta 

% Distribution of Mj parameters
param.m_Ndist       = glob.Ndist.m_Ndist;
param.sigma_Ndist   = glob.Ndist.sigma_Ndist;
param.theta_Ndist   = glob.Ndist.theta_Ndist;  
param.frac_1        = glob.Ndist.frac_1;        % Mass at 1

% Global parameters
varphi              = glob.varphi;
Mj_max              = options.Mj_max;
J                   = glob.J;                   % Number of markets
val.P               = 1;                        % Normalize to 1, final good is numeraire
%__________________________________________________________________________
% Take parameters out of param structure
eta                 = param.eta;
theta               = param.theta;
xi                  = param.xi; 
alpha               = param.alpha;
lambdaK             = glob.lambdaK;             % Fraction of capital that is debt financed
lambdaC             = param.lambdaC;            % CCorp productivity premium

%% 1. DRAW RANDOM VARIABLES
% 1. Draw number of firms Mj in each market j=1,...,J 
u       = rand(J,1);
Mj      = zeros(1,J);
for jj = (1:J)
   ilow = find(glob.Ndist.F_Mj<u(jj),1,'last');
   if isempty(ilow)
       ilow = 1;
   end
   Mj(jj) = glob.Ndist.M_j(ilow);
end
Mj              = Mj'; 
Mj(Mj>=Mj_max)  = Mj_max;           % Truncate number of firms in a market -- hard coded in Nfit!!

u_ij            = random('uniform',0,1,[options.Mj_max,J])  ; 
c_ij            = zeros(options.Mj_max,J);
for jj=1:J
    c_ij(1:Mj(jj),jj) = (u_ij(1:Mj(jj),jj)<share_ccorp)      ; 
end

% 2.  Draw firm level productivities z_ij
z_ij_notilde  = zeros(options.Mj_max,J); %Productivity draws
for jj=1:J
    % xi is the standard deviation of the lognormal
    z_ij_notilde(1:Mj(jj),jj) = random('Lognormal',1,xi,[1,Mj(jj)]);
end  
 
%Scale CCorp productivity
z_ij_notilde(c_ij==1)   = (1+lambdaC)*z_ij_notilde(c_ij==1);
 
%Recover the "tilde z_ij" which is ALWAYS z_ij!
z_ij  = zeros(options.Mj_max,J); %Productivity draws
for jj = (1:J)
    z_ij(1:Mj(jj),jj)=(c_ij(1:Mj(jj),jj)==1).*(1-Delta)*(Delta*(1-tauC)/((1-tauC*lambdaK)*R)).^(Delta/(1-Delta)).*z_ij_notilde(1:Mj(jj),jj).^(1/(1-Delta))...
                     +(c_ij(1:Mj(jj),jj)==0).*(1-Delta)*(Delta/R).^(Delta/(1-Delta)).*z_ij_notilde(1:Mj(jj),jj).^(1/(1-Delta)) ;
end

%% 2. SOLVE MODEL
    
%% A. Solve sectoral equilibria
% Storage for outputs
what_ij         = zeros(Mj_max,J);      % Wage
mu_ij           = zeros(Mj_max,J);      % Markdown
s_ij            = zeros(Mj_max,J);      % Share
eps_ij          = zeros(Mj_max,J);      % Labor supply elasticity
nonconverge_j   = zeros(1,J);           % Non convergence dummies
iterations_j    = zeros(1,J);           % Iterations

for jj=(1:J)     % J regions
    z_i                     = z_ij(1:Mj(jj),jj); % Isolate productivity vector in region
    eq0                     = fun_solve_market_Nash(z_i,param,val,glob,options);
    s_ij(1:Mj(jj),jj)       = eq0.s_i;
    mu_ij(1:Mj(jj),jj)      = eq0.mu_i;
    what_ij(1:Mj(jj),jj)    = eq0.w_i;
    eps_ij(1:Mj(jj),jj)     = eq0.eps_i;
    nonconverge_j(:,jj)     = eq0.non_converge;
    iterations_j(:,jj)      = eq0.iterations;
end

%% B. Construct 'hat' terms
what_j                  = sum(what_ij.^(eta+1)).^(1/(eta+1));
What                    = sum(what_j.^(theta+1)).^(1/(theta+1));
nhat_ij                 = bsxfun(@times,bsxfun(@rdivide,what_ij,what_j).^eta,(what_j/What).^theta).*(What/1).^varphi;

%% C. Compute model averages
AveFirmSizehat_model    = sum(sum(nhat_ij))/sum(Mj);
AveEarningshat_model    = sum(sum(what_ij.*nhat_ij))/sum(sum(nhat_ij));
AveFirmSize_data        = glob.AveFirmSize_data ;% 
AveEarnings_data        = glob.AveEarnings_data ;% 

%% D. Compute varpibar and zbar
if strcmp(options.solve_scale,'Y')
    varphibar           = (AveFirmSize_data/AveFirmSizehat_model)/((AveEarnings_data/AveEarningshat_model).^varphi);
    zbar                = varphibar^(1-alpha) ...
                          * (AveEarnings_data/AveEarningshat_model).^(1+(1-alpha)*varphi) ...
                          * What^(-(1-alpha)*(theta-varphi));
    glob.varphibar      = varphibar;    % Pass out to glob for later counterfactuals
    glob.zbar           = zbar;         % Pass out to glob for later counterfactuals
else
    zbar            = glob.zbar;
    varphibar       = glob.varphibar;
end

%% E. Scale up objects      
omega   = zbar/varphibar^(1-alpha);     % Nuisance parameter
W       = omega^(1/(1+(1-alpha)*varphi)) * What^( (1+(1-alpha)*theta) / (1+(1-alpha)*varphi) ) ;
w_ij    = omega^(1/(1+(1-alpha)*theta)) * W^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij;
w_j     = sum(w_ij.^(eta+1)).^(1/(eta+1));
n_ij    = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij,w_j).^eta,(w_j/W).^theta).*(W/1).^varphi;
n_j     = sum(n_ij.^((eta+1)/eta)).^(eta/(eta+1));
N       = sum(n_j.^((theta+1)/theta)).^(theta/(theta+1));

%% STAIGER SPETZ PHIBBS EXPERIMENT
avg_mkt_wage        = sum(w_ij)./sum(w_ij>0) ;                      % Average wage in the market
avg_mkt_wage_lrg    = repmat( sum(w_ij)./sum(w_ij>0), Mj_max,1) ;   % Average wage in the market

% Select firms so that their wage is on average b/w 1-3% below the market
% wage and face 9-13 competitors.
[rr,cc]         = find( abs(log(avg_mkt_wage_lrg)-log(w_ij))<0.03 & abs(log(avg_mkt_wage_lrg)-log(w_ij))>0.01 & log(avg_mkt_wage_lrg)-log(w_ij)>0 & repmat(Mj',Mj_max,1)>=9 & repmat(Mj',Mj_max,1)<=13);
% One firm per market
rr2             = rr(cc(2:end)~=cc(1:end-1));
cc2             = cc(cc(2:end)~=cc(1:end-1));   
% Matrix index
idx_shock       = sub2ind([Mj_max,J],rr2,cc2);
 
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Staiger shock
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
z_ij1           = z_ij;
z_high          = z_ij*1.3;     % Upper bound on initial guess
z_low           = z_ij;         % Lower bound on iniital guess is no shock
update_speed    = 0.75;

diff            = 10;
diff_max        = 1;

it_max          = 100;
it              = 0;
% Solve model and update guesses of Staiger shock to each 'VA hospital'
while (diff>diff_max) && (it<it_max)
it                  = it+1;
% Bisection on the firm productivity to get to prior market wage
z_ij1(idx_shock)    = 0.5*z_high(idx_shock) + 0.5*z_low(idx_shock);
% Storage for outputs
what_ij1         = zeros(Mj_max,J);      % Wage
mu_ij1           = zeros(Mj_max,J);      % Markdown
s_ij1            = zeros(Mj_max,J);      % Share
eps_ij1          = zeros(Mj_max,J);      % Labor supply elasticity
nonconverge_j1   = zeros(1,J);           % Non convergence dummies
iterations_j1    = zeros(1,J);           % Iterations

% Solve new Nash equilibria in all markets
for jj=(1:J)     % J regions
    z_i1                     = z_ij1(1:Mj(jj),jj); % Isolate productivity vector in region
    eq1                      = fun_solve_market_Nash(z_i1,param,val,glob,options);
    s_ij1(1:Mj(jj),jj)       = eq1.s_i;
    mu_ij1(1:Mj(jj),jj)      = eq1.mu_i;
    what_ij1(1:Mj(jj),jj)    = eq1.w_i;
    eps_ij1(1:Mj(jj),jj)     = eq1.eps_i;
    nonconverge_j1(:,jj)     = eq1.non_converge;
    iterations_j1(:,jj)      = eq1.iterations;
end

%% D. Compute varpibar and zbar
zbar            = glob.zbar;
varphibar       = glob.varphibar;

%% E. Scale up objects
omega   = zbar/varphibar^(1-alpha);   
% PARTIAL EQUILIBRIUM %%%%%%%%%%%%%%%%%% 
W1      = W ;  %[PE]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%__________________________________________________________________________
% Wages and employment
w_ij1   = omega^(1/(1+(1-alpha)*theta)) * W1^( ((1-alpha)*(theta-varphi)) / (1+(1-alpha)*theta) ) .* what_ij1;
w_j1    = sum(w_ij1.^(eta+1)).^(1/(eta+1));
n_ij1   = varphibar*bsxfun(@times,bsxfun(@rdivide,w_ij1,w_j1).^eta,(w_j1/W1).^theta).*(W1/1).^varphi;
%__________________________________________________________________________
% Gap between wage and previous market wage. Algorithm sets this to zero.
gap = w_ij1(idx_shock)-avg_mkt_wage_lrg(idx_shock);  
%__________________________________________________________________________
% Update guesses
for i=1:length(gap)
    % Update bounds of productivity for the shocked firm
    if (gap(i) >0) && (abs(gap(i))>diff_max)
        % If you pay more than prior ave mkt wage, then high is the current value of z
        z_high(idx_shock(i))=(1-update_speed)*z_high(idx_shock(i))+update_speed*z_ij1(idx_shock(i)); 
    elseif (gap(i) <0) && (abs(gap(i))>diff_max)
        % If you pay more than prior ave mkt wage, then low is the current value of z
        z_low(idx_shock(i))=(1-update_speed)* z_low(idx_shock(i))+update_speed*z_ij1(idx_shock(i)); 
    end
end
%__________________________________________________________________________
% Check progress
check_idx=66;
display([ 'it:' num2str(it) ' gap: ' num2str(gap(check_idx)) ' z_high:' num2str(z_high(idx_shock(check_idx))) ' z_low:' num2str(z_low(idx_shock(check_idx))) ' wage:' num2str(w_ij1(idx_shock(check_idx))) 'avg_mkt_wage:' num2str(avg_mkt_wage_lrg(idx_shock(check_idx)))]);
diff        = max(max(abs(gap)));
max_gap     = max(max(abs(gap)));
display([ 'diff:' num2str(diff) ' max gap:' num2str(max_gap)]) ;
end

%% Alternative 
% Compute average competitor wages BEFORE the shock (ie VA wage increase)
w_ij_remove_own             = w_ij;
n_ij_remove_own             = n_ij;
w_ij_remove_own(idx_shock)  = 0;
n_ij_remove_own(idx_shock)  = 0;
wbar_remove_own             = sum(w_ij_remove_own.*n_ij_remove_own)./sum(n_ij_remove_own);
avg_mkt_wage_remove_own     = repmat(wbar_remove_own,Mj_max,1);

% Compute average competitor wages AFTER the shock (ie VA wage increase)
w_ij1_remove_own             = w_ij1;
n_ij1_remove_own             = n_ij1;
w_ij1_remove_own(idx_shock)  = 0;
n_ij1_remove_own(idx_shock)  = 0;
wbar_remove_own1             = sum(w_ij1_remove_own.*n_ij1_remove_own)./sum(n_ij1_remove_own);
avg_mkt_wage_remove_own1     = repmat(wbar_remove_own1,Mj_max,1);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
xxx                         = zeros(size(w_ij));
xxx(idx_shock)              = 1;
xxx                         = (sum(xxx)>0);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Period 0
w_ij0_comp                  = w_ij; 
w_ij0_comp(idx_shock)       = 0;
n_ij0_comp                  = n_ij;

w_ij0_focal                 = zeros(size(w_ij));
w_ij0_focal(idx_shock)      = w_ij(idx_shock);

w_ij0_comp                  = w_ij0_comp(:,xxx);
w_ij0_focal                 = w_ij0_focal(:,xxx);
n_ij0_comp                  = n_ij0_comp(:,xxx);

w_ij0_focal                 = repmat(max(w_ij0_focal,[],1),Mj_max,1);

w_i0_comp                  = w_ij0_comp(:);
w_i0_focal                 = w_ij0_focal(:);
n_i0_comp                  = n_ij0_comp(:);

w_i0_focal                 = w_i0_focal(w_i0_comp>0);
n_i0_comp                  = n_i0_comp(w_i0_comp>0);
w_i0_comp                  = w_i0_comp(w_i0_comp>0);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Period 1
w_ij1_comp                  = w_ij1; 
w_ij1_comp(idx_shock)       = 0;

w_ij1_focal                 = zeros(size(w_ij1));
w_ij1_focal(idx_shock)      = w_ij1(idx_shock);
w_ij1_focal                 = repmat(max(w_ij1_focal,[],1),Mj_max,1);

w_ij1_comp                  = w_ij1_comp(:,xxx);
w_ij1_focal                 = w_ij1_focal(:,xxx);

w_i1_comp                  = w_ij1_comp(:);
w_i1_focal                 = w_ij1_focal(:);

w_i1_focal                 = w_i1_focal(w_i1_comp>0);
w_i1_comp                  = w_i1_comp(w_i1_comp>0);

dlogw_i                     = log(w_i1_comp)-log(w_i0_comp);
dlogwVA_i                   = log(w_i1_focal)-log(w_i0_focal);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Weighted regression (in Staiger et al weighted by 'hopsital beds', here weight
% by employment)
[~,staiger_elast_new2_w] = fun_regression(dlogwVA_i,dlogw_i,n_i0_comp);
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Compute objects following Staiger et al
delta_log_wage_focal        = log(w_ij1)-log(w_ij);
focal_wage_gap              = mean(delta_log_wage_focal(idx_shock));
big_Mj                      = repmat(Mj',Mj_max,1);
focal_no_competitors        = mean(big_Mj(idx_shock));
%-----------------------------------------------------------------------------------%
% REPORT REQUIRED PRODUCTIVITY CHANGES - \psi_{ij}^{SSP} in text
z0 = z_ij(idx_shock);
z1 = z_ij1(idx_shock);
fprintf('Reported in text:\n');
fprintf('mean productivity increase: %4.2f\n',100*(mean(z1./z0)-1));
fprintf('min  productivity increase: %4.2f\n',100*(min(z1./z0)-1));
fprintf('max  productivity increase: %4.2f\n\n',100*(max(z1./z0)-1));
%-----------------------------------------------------------------------------------%
% TABLE
fprintf('Created_table_files/Table_4_Strategic_Interaction_Replication_of_SSP\n');
eval(['fid = fopen(''Created_table_files/Table_4_Strategic_Interaction_Replication_of_SSP.tex'',''w'');']);
fprintf(fid,'\\begin{tabular}{lcccc}\n');
fprintf(fid,'\\toprule\n');
fprintf(fid,'& & \\multicolumn{1}{c}{\\textbf{Model}}  & & \\multicolumn{1}{c}{\\textbf{Data}}  \\\\ \n'); 
fprintf(fid,'\\midrule  \n');
fprintf(fid,'\\textbf{A. Replication statistics} \\\\ \n');
fprintf(fid,'Average log difference (gap) between VA hospital wage and average competitor wage  &  & %2.3f    & & %2.3f    \\\\ \n', mean(focal_wage_gap) , 0.019);
fprintf(fid,'Average number of firms in a market &  & %2.1f    & & %2.1f    \\\\ \n', mean(focal_no_competitors) , 10.9);
fprintf(fid,'Average productivity increase to set gap to zero &  &     & & %2.1f    \\\\ \n', mean(z1./z0));
fprintf(fid,'\\midrule  \n'); 
fprintf(fid,'\\textbf{B. Result} \\\\ \n');
fprintf(fid,'Elasticity of competitor wages to VA hospital wage & & %2.3f    & & %2.3f    \\\\ \n', staiger_elast_new2_w , .128);
fprintf(fid,'$\\quad\\quad$(Standard error) & &     & & (%2.3f)    \\\\ \n',0.033);
fprintf(fid,'\\bottomrule \n');
fprintf(fid,'\\end{tabular}');
fclose(fid);
%-----------------------------------------------------------------------------------%

return
